@@ -521,7 +521,6 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
     commits = []
     for changeSet in arr:
         files = []
-
         items = changeSet.get('items', {})
         # print(changeSet)
         changesetId = changeSet.get('changeset')
@@ -534,7 +533,7 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
             else:
                 raise Exception("changesetId is not set")
 
-        date = changeSet['date']
+        date = changeSet.get('date', datetime.now().strftime("%A, %B %d, %Y %I:%M:%S %p"))
 
         for key in items:
             if ',' in key:
@@ -603,14 +602,13 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
         removed = [x for x in files if 'delete' in x['status']]
         renamed = [x for x in files if 'rename' in x['status']]
         try:
-            datetime_object = datetime.strptime(
-                date, "%A, %B %d, %Y %I:%M:%S %p")
+            datetime_object = datetime.strptime(date, "%A, %B %d, %Y %I:%M:%S %p")
             date = datetime_object.strftime("%Y-%m-%dT%H:%M:%S")
         except ValueError:
             datetime_object = datetime.strptime(date, "%Y-%m-%d %H:%M:%S")
             date = datetime_object.strftime("%Y-%m-%dT%H:%M:%S")
         else:
-            pass
+            date = datetime.now().strftime("%Y-%m-%dT%H:%M:%S")
 
         commit = {
             'files': files,
