@@ -34,6 +34,9 @@ def to_iso(data):
         return data
 
 def get_last_branch_changeSet(branch, numberOfChangets):
+    # output = execute(MoveToMainDirectory + TF_Branches_History.format(branch) + (
+    #     "" if numberOfChangets == None else " /stopafter:{}".format(numberOfChangets)))
+
     changeSetList = []
     # changeSetDict = {}
     # propertyName = ""
@@ -106,6 +109,8 @@ def get_last_branch_changeSet(branch, numberOfChangets):
     return changeSetList
 
 
+
+
 def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequired=True, shouldRunRestApi=False):
     length = len(arr)
 
@@ -125,7 +130,7 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
             else:
                 raise Exception("changesetId is not set")
 
-        date = changeSet['date']
+        date = changeSet.get('date', datetime.now().strftime("%A, %B %d, %Y %I:%M:%S %p"))
 
         for key in items:
             if ',' in key:
@@ -201,7 +206,7 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
             datetime_object = datetime.strptime(date, "%Y-%m-%d %H:%M:%S")
             date = datetime_object.strftime("%Y-%m-%dT%H:%M:%S")
         else:
-            pass
+            date = datetime.now().strftime("%Y-%m-%dT%H:%M:%S")
 
         commit = {
             'files': files,
@@ -273,11 +278,11 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
                         file['additions'] for file in value['files'])
 
         value['stats']['deletions'] = reduce(
-            lambda x, y: x + y['deletions'], value['files'], 0)
+            lambda x, y: x+y['deletions'], value['files'], 0)
         value['stats']['additions'] = reduce(
-            lambda x, y: x + y['additions'], value['files'], 0)
+            lambda x, y: x+y['additions'], value['files'], 0)
         value['stats']['changes'] = value['stats']['deletions'] + \
-                                    value['stats']['additions']
+            value['stats']['additions']
         value['stats']['total'] = value['stats']['changes']
 
     data = {
